@@ -898,7 +898,7 @@ struct local_info {
 #endif /* PRISM2_PCCARD */
 
 #ifdef PRISM2_PLX
-	unsigned long attr_mem;
+	void *attr_mem;
 	unsigned int cor_offset;
 #endif /* PRISM2_PLX */
 
@@ -912,7 +912,9 @@ struct local_info {
 	struct sk_buff *rx_skb;
 #endif /* PRISM2_BUS_MASTER */
 #ifdef CONFIG_PM
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,10))
 	u32 pci_save_state[16];
+#endif
 #endif /* CONFIG_PM */
 #endif /* PRISM2_PCI */
 
@@ -1011,7 +1013,8 @@ enum { BAP0 = 0, BAP1 = 1 };
 static inline void prism2_io_debug_add(struct net_device *dev, int cmd,
 				       int reg, int value)
 {
-	local_info_t *local = dev->priv;
+	struct hostap_interface *iface = dev->priv;
+	local_info_t *local = iface->local;
 
 	if (!local->io_debug_enabled)
 		return;
@@ -1028,7 +1031,8 @@ static inline void prism2_io_debug_add(struct net_device *dev, int cmd,
 
 static inline void prism2_io_debug_error(struct net_device *dev, int err)
 {
-	local_info_t *local = dev->priv;
+	struct hostap_interface *iface = dev->priv;
+	local_info_t *local = iface->local;
 	unsigned long flags;
 
 	if (!local->io_debug_enabled)
